package com.ruoyi.kaohe.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.kaohe.mapper.KhTemplateMapper;
import com.ruoyi.kaohe.domain.KhTemplate;
import com.ruoyi.kaohe.service.IKhTemplateService;

/**
 * 考核模板Service业务层处理
 * 
 * @author hs
 * @date 2025-06-17
 */
@Service
public class KhTemplateServiceImpl implements IKhTemplateService 
{
    @Autowired
    private KhTemplateMapper khTemplateMapper;

    /**
     * 查询考核模板
     * 
     * @param id 考核模板主键
     * @return 考核模板
     */
    @Override
    public KhTemplate selectKhTemplateById(Long id)
    {
        return khTemplateMapper.selectKhTemplateById(id);
    }

    /**
     * 查询考核模板列表
     * 
     * @param khTemplate 考核模板
     * @return 考核模板
     */
    @Override
    public List<KhTemplate> selectKhTemplateList(KhTemplate khTemplate)
    {
        return khTemplateMapper.selectKhTemplateList(khTemplate);
    }

    /**
     * 新增考核模板
     * 
     * @param khTemplate 考核模板
     * @return 结果
     */
    @Override
    public int insertKhTemplate(KhTemplate khTemplate)
    {
        return khTemplateMapper.insertKhTemplate(khTemplate);
    }

    /**
     * 修改考核模板
     * 
     * @param khTemplate 考核模板
     * @return 结果
     */
    @Override
    public int updateKhTemplate(KhTemplate khTemplate)
    {
        return khTemplateMapper.updateKhTemplate(khTemplate);
    }

    /**
     * 批量删除考核模板
     * 
     * @param ids 需要删除的考核模板主键
     * @return 结果
     */
    @Override
    public int deleteKhTemplateByIds(Long[] ids)
    {
        return khTemplateMapper.deleteKhTemplateByIds(ids);
    }

    /**
     * 删除考核模板信息
     * 
     * @param id 考核模板主键
     * @return 结果
     */
    @Override
    public int deleteKhTemplateById(Long id)
    {
        return khTemplateMapper.deleteKhTemplateById(id);
    }
}
